@@ -1,7 +1,7 @@
 /*
  * applications.h - the Qucs application list
  *
- * Copyright (C) 2005, 2006, 2007, 2008 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2005, 2006, 2007, 2008, 2009 Stefan Jahn <stefan@lkcc.org>
  * Copyright (C) 2006 Gunther Kraut <gn.kraut@t-online.de>
  *
  * This is free software; you can redistribute it and/or modify
@@ -19,7 +19,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: applications.h,v 1.31 2008/03/27 17:34:29 ela Exp $
+ * $Id: applications.h,v 1.34 2009/04/19 12:01:33 ela Exp $
  *
  */
 
@@ -149,6 +149,11 @@ struct application_t eqn::applications[] = {
   { "^", TAG_VECTOR,  evaluate::power_v_c, 2, { TAG_VECTOR,  TAG_COMPLEX } },
   { "^", TAG_VECTOR,  evaluate::power_c_v, 2, { TAG_COMPLEX, TAG_VECTOR  } },
   { "^", TAG_VECTOR,  evaluate::power_v_v, 2, { TAG_VECTOR,  TAG_VECTOR  } },
+  { "^", TAG_MATRIX,  evaluate::power_m_d, 2, { TAG_MATRIX,  TAG_DOUBLE  } },
+  { "^", TAG_MATRIX,  evaluate::power_m_c, 2, { TAG_MATRIX,  TAG_COMPLEX } },
+  { "^", TAG_MATVEC,  evaluate::power_mv_d, 2, { TAG_MATVEC, TAG_DOUBLE  } },
+  { "^", TAG_MATVEC,  evaluate::power_mv_c, 2, { TAG_MATVEC, TAG_COMPLEX } },
+  { "^", TAG_MATVEC,  evaluate::power_mv_v, 2, { TAG_MATVEC, TAG_VECTOR  } },
 
   { "hypot", TAG_DOUBLE,  evaluate::xhypot_d_d, 2,
     { TAG_DOUBLE,  TAG_DOUBLE  } },
@@ -665,6 +670,7 @@ struct application_t eqn::applications[] = {
     { TAG_VECTOR, TAG_VECTOR } },
   { "Freq2Time", TAG_VECTOR, evaluate::freq2time_v_v, 2,
     { TAG_VECTOR, TAG_VECTOR } },
+  { "fftshift",  TAG_VECTOR, evaluate::fftshift_v, 1, { TAG_VECTOR } },
 
   { "xvalue", TAG_COMPLEX, evaluate::xvalue_d, 2,
     { TAG_VECTOR, TAG_DOUBLE } },
