@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: characteristic.h,v 1.2 2007/09/16 16:49:38 ela Exp $
+ * $Id: characteristic.h,v 1.3 2008/01/13 12:15:27 ela Exp $
  *
  */
 
@@ -27,7 +27,7 @@
 
 #include "pair.h"
 
-class characteristic : public pair
+class characteristic : public ::pair
 {
  public:
   characteristic ();
