@@ -1,7 +1,7 @@
 /*
  * check_dataset.h - checker definitions for the Qucs dataset
  *
- * Copyright (C) 2003, 2005 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2003, 2005, 2006 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: check_dataset.h,v 1.3 2005/06/02 18:17:49 raimi Exp $
+ * $Id: check_dataset.h,v 1.5 2006/02/06 09:50:15 raimi Exp $
  *
  */
 
@@ -32,6 +32,7 @@ extern strlist * dataset_idents;
 /* Externalize variables used by the scanner and parser. */
 extern int dataset_lineno;
 extern FILE * dataset_in;
+void dataset_restart (FILE *);
 
 __BEGIN_DECLS
 
@@ -39,6 +40,7 @@ __BEGIN_DECLS
 int dataset_parse (void);
 int dataset_error (char *);
 int dataset_lex (void);
+int dataset_lex_destroy (void);
 int dataset_check (dataset *);
 
 __END_DECLS
