@@ -1,7 +1,7 @@
 /*
  * check_netlist.cpp - checker for the Qucs netlist
  *
- * Copyright (C) 2003-2008 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2003-2009 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: check_netlist.cpp,v 1.122 2008/02/22 16:55:19 ela Exp $
+ * $Id: check_netlist.cpp,v 1.131 2009/04/16 15:14:55 ela Exp $
  *
  */
 
@@ -41,20 +41,13 @@
 #include "constants.h"
 #include "environment.h"
 #include "variable.h"
+#include "module.h"
 
 /* Global definitions for parser and checker. */
 struct definition_t * definition_root = NULL;
 struct definition_t * subcircuit_root = NULL;
 environment * env_root = NULL;
 
-// Include list of available components.
-#include "qucsdefs.h"
-
-// List of available microstrip components.
-static const char * strip_available[] = {
-  "MLIN", "MCORN", "MMBEND", "MSTEP", "MOPEN", "MGAP", "MCOUPLED", "MTEE",
-  "MCROSS", "MVIA", "CLIN", "COPEN", "CSHORT", "CGAP", "CSTEP", "BOND", NULL };
-
 /* The function counts the nodes in a definition line. */
 static int checker_count_nodes (struct definition_t * def) {
   int count = 0;
@@ -67,39 +60,37 @@ static int checker_count_nodes (struct definition_t * def) {
    type.  If there is no such definition type the function returns
    NULL. */
 static struct define_t * checker_find_definition (char * type, int action) {
-  struct define_t * def;
-  for (def = qucs_definition_available; def->type != NULL; def++) {
-    if (!strcmp (type, def->type) && action == def->action)
-      return def;
-  }
+  struct define_t * def = module::getModule (type);
+  if (def != NULL && action == def->action) return def;
   return NULL;
 }
 
 /* The function returns the number of properties in a definition line
    specified by the given key. */
-static int checker_find_property (const char * key, struct pair_t * pair) {
+static int checker_find_property (const char * key, struct pair_t * pp) {
   int count = 0;
-  while (pair != NULL) {
-    if (!strcmp (pair->key, key))
+  while (pp != NULL) {
+    if (!strcmp (pp->key, key))
       count++;
-    pair = pair->next;
+    pp = pp->next;
   }
   return count;
 }
 
 /* Checks if the given property key is either optional or required for
-   the given definition type. */
-static int checker_is_property (struct define_t * available, char * key) {
+   the given definition type and returns the type of the property. */
+static int checker_is_property (struct define_t * available,
+				const char * key) {
   int i;
   for (i = 0; PROP_IS_PROP (available->required[i]); i++) {
     if (!strcmp (available->required[i].key, key))
-      return 1;
+      return available->required[i].type;
   }
   for (i = 0; PROP_IS_PROP (available->optional[i]); i++) {
     if (!strcmp (available->optional[i].key, key))
-      return 1;
+      return available->optional[i].type;
   }
-  return 0;
+  return PROP_NONE;
 }
 
 /* Counts the number of definitions given by the specified type and
@@ -187,122 +178,6 @@ static struct value_t * checker_validate_reference (struct definition_t * def,
   return val;
 }
 
-/* Structure defining a certain component type containing special
-   parameter values. */
-struct special_t {
-  const char * type;     // component type
-  const char * key;      // parameter name
-  const char * value[8]; // maximum 7 alternatives for now
-};
-
-// List of special identifiers.
-static struct special_t checker_specials[] = {
-  { "JFET",   "Type",        { "nfet", "pfet", NULL } },
-  { "BJT",    "Type",        { "npn", "pnp", NULL } },
-  { "MOSFET", "Type",        { "nfet", "pfet", NULL } },
-  { "SP",     "Noise",       { "yes", "no", NULL } },
-  { "SP",     "saveCVs",     { "yes", "no", NULL } },
-  { "SP",     "saveAll",     { "yes", "no", NULL } },
-  { "SP",     "Type",        { "lin", "log", "list", "const", NULL } },
-  { "AC",     "Type",        { "lin", "log", "list", "const", NULL } },
-  { "AC",     "Noise",       { "yes", "no", NULL } },
-  { "DC",     "saveOPs",     { "yes", "no", NULL } },
-  { "DC",     "saveAll",     { "yes", "no", NULL } },
-  { "DC",     "convHelper",  { "none", "SourceStepping", "gMinStepping", 
-			       "LineSearch", "Attenuation", "SteepestDescent",
-			       NULL } },
-  { "DC",     "Solver",      { "CroutLU", "DoolittleLU", "HouseholderQR",
-			       "HouseholderLQ", "GolubSVD", NULL } },
-  { "TR",     "Type",        { "lin", "log", NULL } },
-  { "TR",     "IntegrationMethod",
-    { "Euler", "Trapezoidal", "Gear", "AdamsMoulton", NULL } },
-  { "TR",     "Solver",      { "CroutLU", "DoolittleLU", "HouseholderQR",
-			       "HouseholderLQ", "GolubSVD", NULL } },
-  { "TR",     "relaxTSR",    { "yes", "no", NULL } },
-  { "TR",     "initialDC",   { "yes", "no", NULL } },
-  { "MLIN",   "DispModel",   { "Kirschning", "Kobayashi", "Yamashita",
-			       "Getsinger", "Schneider", "Pramanick",
-			       "Hammerstad", NULL } },
-  { "MLIN",   "Model",       { "Wheeler", "Schneider", "Hammerstad", NULL } },
-  { "CLIN",   "Backside",    { "Metal", "Air", NULL } },
-  { "CLIN",   "Approx",      { "yes", "no", NULL } },
-  { "COPEN",  "Backside",    { "Metal", "Air", NULL } },
-  { "CSHORT", "Backside",    { "Metal", "Air", NULL } },
-  { "CSTEP",  "Backside",    { "Metal", "Air", NULL } },
-  { "SW",     "Type",        { "lin", "log", "list", "const", NULL } },
-  { "SPfile", "Data",        { "rectangular", "polar", NULL } },
-  { "SPfile", "Interpolator",{ "linear", "cubic", NULL } },
-  { "SPfile", "duringDC",    { "open", "short", "shortall", "unspecified",
-			       NULL } },
-  { "DigiSource", "init",    { "low", "high", NULL } },
-  { "Switch", "init",        { "on", "off", NULL } },
-  { "MSTEP",  "MSDispModel", { "Kirschning", "Kobayashi", "Yamashita",
-			       "Getsinger", "Schneider", "Pramanick",
-			       "Hammerstad", NULL } },
-  { "MSTEP",  "MSModel",     { "Wheeler", "Schneider", "Hammerstad", NULL } },
-  { "MOPEN",  "MSDispModel", { "Kirschning", "Kobayashi", "Yamashita",
-			       "Getsinger", "Schneider", "Pramanick",
-			       "Hammerstad", NULL } },
-  { "MOPEN",  "MSModel",     { "Wheeler", "Schneider", "Hammerstad", NULL } },
-  { "MOPEN",  "Model",       { "Kirschning", "Hammerstad",
-			       "Alexopoulos", NULL } },
-  { "MGAP",   "MSDispModel", { "Kirschning", "Kobayashi", "Yamashita",
-			       "Getsinger", "Schneider", "Pramanick",
-			       "Hammerstad", NULL } },
-  { "MGAP",   "MSModel",     { "Wheeler", "Schneider", "Hammerstad", NULL } },
-  { "MCOUPLED", "Model",     { "Kirschning", "Hammerstad", NULL } },
-  { "MCOUPLED", "DispModel", { "Kirschning", "Getsinger", NULL } },
-  { "MTEE",   "MSDispModel", { "Kirschning", "Kobayashi", "Yamashita",
-			       "Getsinger", "Schneider", "Pramanick",
-			       "Hammerstad", NULL } },
-  { "MTEE",   "MSModel",     { "Wheeler", "Schneider", "Hammerstad", NULL } },
-  { "MCROSS", "MSDispModel", { "Kirschning", "Kobayashi", "Yamashita",
-			       "Getsinger", "Schneider", "Pramanick",
-			       "Hammerstad", NULL } },
-  { "MCROSS", "MSModel",     { "Wheeler", "Schneider", "Hammerstad", NULL } },
-  { "hicumL2p1", "Type",     { "npn", "pnp", NULL } },
-  { "BOND",   "Model",       { "FREESPACE", "MIRROR", "DESCHARLES", NULL } },
-  { "Vfile", "Interpolator", { "hold", "linear", "cubic", NULL } },
-  { "Vfile", "Repeat",       { "no", "yes", NULL } },
-  { "Ifile", "Interpolator", { "hold", "linear", "cubic", NULL } },
-  { "Ifile", "Repeat",       { "no", "yes", NULL } },
-  { "RFEDD", "Type",         { "Y", "Z", "S", "H", "G", "A", "T", NULL } },
-  { "RFEDD", "duringDC",     { "open", "short", "unspecified",
-			       "zerofrequency", NULL } },
-  { NULL, NULL, { NULL } }
-};
-
-/* This function checks whether the given identifier which occurred in
-   a component property (may also be a variable) is a special
-   identifier used for some properties. It returns zero if the
-   identifier is invalid. */
-static int checker_validate_special (struct definition_t * root,
-				     struct definition_t * def, char * ident) {
-  int found = 0;
-  struct value_t * val;
-  struct special_t * special;
-  // go through each special
-  for (int i = 0; checker_specials[i].type != NULL; i++) {
-    special = &checker_specials[i];
-    // find the given identifier in the list of allowed specials
-    val = checker_find_variable (root, special->type, special->key, ident);
-    if (val != NULL) {
-      // check whether the given identifier is an allowed value
-      for (int n = 0; special->value[n] != NULL; n++) {
-	if (!strcmp (special->value[n], ident)) {
-	  found++;
-	}
-      }
-      if (!found) {
-	logprint (LOG_ERROR, "line %d: checker error, `%s' is not a valid "
-		  "`%s' property as used in `%s:%s'\n", def->line, ident,
-		  special->key, def->type, def->instance);
-      }
-    }
-  }
-  return found;
-}
-
 /* This function checks whether the given definition is a known
    microstrip component with a substrate definition.  If the given
    identifier equals this substrate definition then the function
@@ -310,31 +185,52 @@ static int checker_validate_special (struct definition_t * root,
 static struct value_t * checker_find_substrate (struct definition_t * def,
 						char * ident) {
   struct value_t * val;
-  for (int i = 0; strip_available[i] != NULL; i++) {
-    if (!strcmp (strip_available[i], def->type)) {
-      if ((val = checker_find_reference (def, "Subst")) != NULL) {
-	if (ident != NULL && !strcmp (val->ident, ident))
-	  return val;
-      }
+  if (checker_is_property (def->define, "Subst") == PROP_STR) {
+    if ((val = checker_find_reference (def, "Subst")) != NULL) {
+      if (ident != NULL && !strcmp (val->ident, ident))
+	return val;
     }
   }
   return NULL;
 }
 
+/* Puts the given double value variable into an environment. */
+static variable * checker_add_variable (environment * env,
+					char * var, int type, bool pass) {
+  variable * v = new variable (var);
+  eqn::constant * c = new eqn::constant (type);
+  switch (type) {
+    case TAG_DOUBLE:
+      c->d = 0.0; // initialize the variable
+      break;
+    case TAG_VECTOR:
+      c->v = new vector ();
+      break;
+  }
+  v->setConstant (c);
+  env->addVariable (v, pass);
+  return v;
+}
+
 /* Resolves the variable of a property value.  Returns non-zero on
    success, otherwise zero. */
 static int checker_resolve_variable (struct definition_t * root,
 				     struct definition_t * def,
-				     struct value_t * value) {
+				     struct pair_t * pair, int type) {
   struct value_t * val;
+  struct value_t * value = pair->value;
   if (value->ident != NULL) {
     int found = 0;
     /* 1. find variable in parameter sweeps */
     if ((val = checker_find_variable (root, "SW", "Param", value->ident))) {
+      /* add parameter sweep variable to environment */
+      if (!strcmp (def->type, "SW") && !strcmp (pair->key, "Param")) {
+	checker_add_variable (root->env, value->ident, TAG_DOUBLE, true);
+      }
       /* mark both the variable identifier and the parameter sweep
 	 variable to be actually variables */
-      val->var = eqn::TAG_DOUBLE;
-      value->var = eqn::TAG_DOUBLE;
+      val->var = TAG_DOUBLE;
+      value->var = TAG_DOUBLE;
       found++;
     }
     /* 2. find analysis in parameter sweeps */
@@ -351,7 +247,7 @@ static int checker_resolve_variable (struct definition_t * root,
       found++;
     }
     /* 5. find special identifiers in certain properties */
-    if (checker_validate_special (root, def, value->ident)) {
+    if (value->range) {
       found++;
     }
     /* 6. find file reference in S-parameter file components */
@@ -362,13 +258,10 @@ static int checker_resolve_variable (struct definition_t * root,
     if (root->env) {
       if (root->env->getChecker()->containsVariable (value->ident)) {
 	variable * v;
-	value->var = eqn::TAG_DOUBLE;
+	value->var = (type == PROP_LIST) ? TAG_VECTOR : TAG_DOUBLE;
 	if ((v = root->env->getVariable (value->ident)) == NULL) {
 	  // put variable into the environment
-	  v = new variable (value->ident);
-	  eqn::constant * c = new eqn::constant (eqn::TAG_DOUBLE);
-	  v->setConstant (c);
-	  root->env->addVariable (v, false);
+	  checker_add_variable (root->env, value->ident, value->var, false);
 	}
 	found++;
       }
@@ -380,6 +273,39 @@ static int checker_resolve_variable (struct definition_t * root,
     if ((val = checker_find_variable (root, "Ifile", "File", value->ident))) {
       found++;
     }
+    /* 9. find property reference in the instance */
+    if (!found &&
+	checker_is_property (def->define, value->ident) != PROP_NONE) {
+      if (root->env) {
+
+	// create reference variable names
+	char * txt = (char *)
+	  malloc (strlen (def->instance) + 1 + strlen (value->ident) + 1);
+	sprintf (txt, "%s.%s", def->instance, value->ident);
+	char * ref = (char *)
+	  malloc (strlen (def->instance) + 5 + strlen (value->ident) + 1);
+	sprintf (ref, "%s.%s.ref", def->instance, value->ident);
+
+	// replace property string
+	free (value->ident);
+	value->ident = strdup (ref);
+	value->var = TAG_DOUBLE;
+
+	// already done previously?
+	variable * v;
+	if ((v = root->env->getVariable (ref)) == NULL) {
+	  // put variable into the environment
+	  checker_add_variable (root->env, ref, TAG_DOUBLE, false);
+	  // also add reference equation into environment
+	  root->env->getChecker()->addReference ("#propref", ref, txt);
+	}
+
+	// done
+	free (txt);
+	free (ref);
+	found++;
+      }
+    }
     /* not found */
     if (!found) {
       logprint (LOG_ERROR, "line %d: checker error, no such variable `%s' "
@@ -671,10 +597,17 @@ static int checker_validate_lists (struct definition_t * root) {
       if (type && (!strcmp (type, "const") || !strcmp (type, "list"))) {
 	// property 'Values' is required
 	if ((val = checker_find_prop_value (def, "Values")) == NULL) {
-	  logprint (LOG_ERROR, "line %d: checker error, required property "
-		    "`%s' not found in `%s:%s'\n", def->line, "Values",
-		    def->type, def->instance);
-	  errors++;
+	  if (!strcmp (type, "const")) {
+	    if ((val = checker_validate_reference (def, "Values")) == NULL) {
+	      errors++;
+	    }
+	  }
+	  else {
+	    logprint (LOG_ERROR, "line %d: checker error, required property "
+		      "`%s' not found in `%s:%s'\n", def->line, "Values",
+		      def->type, def->instance);
+	    errors++;
+	  }
 	}
 	else {
 	  if (!strcmp (type, "const")) {
@@ -686,8 +619,11 @@ static int checker_validate_lists (struct definition_t * root) {
 			def->type, def->instance);
 	      errors++;
 	    }
+	    val->var = TAG_UNKNOWN;
+	  }
+	  if (!strcmp (type, "list")) {
+	    val->var = TAG_VECTOR;
 	  }
-	  val->var = eqn::TAG_VECTOR;
 	  // check and evaluate the unit scale in a value list
 	  for (; val != NULL; val = val->next) {
 	    if (!checker_evaluate_scale (val))
@@ -799,28 +735,26 @@ static int checker_validate_strips (struct definition_t * root) {
   struct value_t * val;
   for (struct definition_t * def = root; def != NULL; def = def->next) {
     if (!def->action) {
-      /* find microstrip components */
-      for (int i = 0; strip_available[i] != NULL; i++) {
-	if (!strcmp (strip_available[i], def->type)) {
-	  /* check validity of 'Subst' property */
-	  if ((val = checker_validate_reference (def, "Subst")) == NULL) {
-	    errors++;
-	  }
-	  else {
-	    if (checker_count_definition (root, "SUBST", val->ident) != 1) {
-	      logprint (LOG_ERROR, "line %d: checker error, no such substrate "
-			"`%s' found as specified in `%s:%s'\n", def->line,
-			val->ident, def->type, def->instance);
-	      errors++;
-	    }
-	  }
-	  /* check validity of 'Model' property */
-#if DISABLE_FOR_NOW /* ThinkME!!! */
-	  if ((val = checker_validate_reference (def, "Model")) == NULL) {
-	    errors++;
-	  }
-#endif
+      /* find components with substrate property */
+      if (checker_is_property (def->define, "Subst") == PROP_STR) {
+	/* check validity of 'Subst' property */
+	if ((val = checker_validate_reference (def, "Subst")) == NULL) {
+	  errors++;
 	}
+	else {
+	  if (checker_count_definition (root, "SUBST", val->ident) != 1) {
+	    logprint (LOG_ERROR, "line %d: checker error, no such substrate "
+		      "`%s' found as specified in `%s:%s'\n", def->line,
+		      val->ident, def->type, def->instance);
+	    errors++;
+	  }
+	}
+	/* check validity of 'Model' property */
+#if DISABLE_FOR_NOW /* ThinkME!!! */
+	if ((val = checker_validate_reference (def, "Model")) == NULL) {
+	  errors++;
+	}
+#endif
       }
     }
   }
@@ -953,25 +887,25 @@ int netlist_checker_variables (environment * env) {
    inside the allowed range defined by the given property definition
    and returns the number of error or zero otherwise. */
 static int checker_value_in_prop_range (char * instance, struct define_t * def,
-					struct pair_t * pair,
+					struct pair_t * pp,
 					struct property_t * prop) {
   int errors = 0;
   // check values
   if (PROP_IS_VAL (*prop)) {
     if (!PROP_IS_LST (*prop)) {
       // lists of values possible?
-      if (pair->value->next != NULL) {
+      if (pp->value->next != NULL) {
 	logprint (LOG_ERROR,
 		  "checker error, value of `%s' needs to be "
 		  "a single value in `%s:%s', no lists possible\n",
-		  pair->key, def->type, instance);
+		  pp->key, def->type, instance);
 	errors++;
       }
     }
     else {
       // a value list
-      struct value_t * val = pair->value;
-      val->var = eqn::TAG_VECTOR;
+      struct value_t * val = pp->value;
+      val->var = TAG_VECTOR;
       // check and evaluate the unit scale in a value list
       for (; val != NULL; val = val->next) {
 	if (!checker_evaluate_scale (val))
@@ -980,13 +914,13 @@ static int checker_value_in_prop_range (char * instance, struct define_t * def,
     }
     // check range of all values
     if (PROP_HAS_RANGE (*prop)) {
-      struct value_t * val = pair->value;
+      struct value_t * val = pp->value;
       if (val->ident) {
 	/* no range checking on variable identifier */
 	logprint (LOG_STATUS, 
 		  "checker notice, value of `%s' (variable `%s') could be "
 		  "out of range `%c%g,%g%c' in `%s:%s'\n",
-		  pair->key, val->ident, prop->range.il, prop->range.l,
+		  pp->key, val->ident, prop->range.il, prop->range.l,
 		  prop->range.h, prop->range.ih, def->type, instance);
 	val = NULL;
       }
@@ -1004,7 +938,7 @@ static int checker_value_in_prop_range (char * instance, struct define_t * def,
 	  logprint (LOG_ERROR, 
 		    "checker error, value of `%s' (%g) is out of "
 		    "range `%c%g,%g%c' in `%s:%s'\n",
-		    pair->key, val->value, prop->range.il, prop->range.l,
+		    pp->key, val->value, prop->range.il, prop->range.l,
 		    prop->range.h, prop->range.ih, def->type, instance);
 	  errors++;
 	}
@@ -1013,24 +947,46 @@ static int checker_value_in_prop_range (char * instance, struct define_t * def,
     // check fraction of integers
     if (PROP_IS_INT (*prop)) {
       double integral;
-      if (modf (pair->value->value, &integral) != 0) {
+      if (modf (pp->value->value, &integral) != 0) {
 	logprint (LOG_ERROR,
 		  "checker error, value of `%s' (%g) needs to be "
 		  "an integer in `%s:%s'\n",
-		  pair->key, pair->value->value, def->type, instance);
+		  pp->key, pp->value->value, def->type, instance);
 	errors++;
       }
     }
   }      
   // check identifiers
   else {
-    if (pair->value->ident == NULL) {
+    // no identifier given
+    if (pp->value->ident == NULL) {
       logprint (LOG_ERROR,
 		"checker error, value of `%s' (%g) needs to be "
 		"an identifier in `%s:%s'\n",
-		pair->key, pair->value->value, def->type, instance);
+		pp->key, pp->value->value, def->type, instance);
       errors++;
     }
+    // check identifier range
+    else {
+      if (PROP_HAS_STR (*prop)) {
+	int i, found = 0;
+	char range[256]; sprintf (range, "[");
+	for (i = 0; prop->range.str[i]; i++) {
+	  strcat (range, prop->range.str[i]);
+	  strcat (range, ",");
+	  if (!strcmp (prop->range.str[i], pp->value->ident)) found++;
+	}
+	if (!found) {
+	  range[strlen (range) - 1] = ']';
+	  logprint (LOG_ERROR,
+		    "checker error, value of `%s' (%s) needs to be "
+		    "in %s in `%s:%s'\n",
+		    pp->key, pp->value->ident, range, def->type, instance);
+	  errors++;
+	}
+	else pp->value->range = 1;
+      }
+    }
   }
   return errors;
 }
@@ -1039,19 +995,19 @@ static int checker_value_in_prop_range (char * instance, struct define_t * def,
    part of the available definition is inside the allowed range and
    returns zero if not.  Otherwise the function returns non-zero. */
 static int checker_value_in_range (char * instance, struct define_t * def,
-				   struct pair_t * pair) {
+				   struct pair_t * pp) {
   int i, errors = 0;
   // go through required properties
   for (i = 0; PROP_IS_PROP (def->required[i]); i++) {
-    if (!strcmp (def->required[i].key, pair->key)) {
-      errors += checker_value_in_prop_range (instance, def, pair,
+    if (!strcmp (def->required[i].key, pp->key)) {
+      errors += checker_value_in_prop_range (instance, def, pp,
 					     &def->required[i]);
     }
   }
   // go through optional properties
   for (i = 0; PROP_IS_PROP (def->optional[i]); i++) {
-    if (!strcmp (def->optional[i].key, pair->key)) {
-      errors += checker_value_in_prop_range (instance, def, pair,
+    if (!strcmp (def->optional[i].key, pp->key)) {
+      errors += checker_value_in_prop_range (instance, def, pp,
 					     &def->optional[i]);
     }
   }
@@ -1179,6 +1135,9 @@ checker_copy_subcircuit_nodes (struct definition_t * type,
     else if (!strcmp (n->node, "gnd")) { // ground node
       ncopy->node = strdup (n->node);
     }
+    else if (n->node[strlen (n->node) - 1] == '!') { // global node
+      ncopy->node = strdup (n->node);
+    }
     else { // internal subcircuit element node
       ncopy->node = checker_subcircuit_node (type->instance, instances,
 					     inst->instance, n->node);
@@ -1244,6 +1203,9 @@ checker_copy_circuit_nodes (struct definition_t * type,
       else if (!strcmp (n->node, "gnd")) { // global ground node
 	ncopy->node = strdup (n->node);
       }
+      else if (n->node[strlen (n->node) - 1] == '!') { // other global node
+	ncopy->node = strdup (n->node);
+      }
       else { // internal subcircuit element node
 	ncopy->node = checker_subcircuit_node (type->instance, instances,
 					       inst->instance, n->node);
@@ -1453,6 +1415,20 @@ static struct define_t * netlist_create_define (struct definition_t * def) {
   d->type = strdup (def->instance);
   d->nodes = checker_count_nodes (def);
   d->action = PROP_COMPONENT;
+
+  // determine number of required and optional parameters
+  for (o = r = 0, p = def->pairs; p != NULL; p = p->next) {
+    if (p->value == NULL)
+      r++;
+    else
+      o++;
+  }
+  d->required =
+    (struct property_t *) calloc (sizeof (struct property_t), r + 2);
+  d->optional =
+    (struct property_t *) calloc (sizeof (struct property_t), o + 1);
+
+  // fill in parameters
   for (o = r = 0, p = def->pairs; p != NULL; p = p->next) {
     if (p->value == NULL) {
       // required
@@ -1501,10 +1477,12 @@ static void netlist_free_define (struct define_t * d) {
   for (i = 0, p = d->required; p[i].key != NULL; i++) {
     free ((char *) p[i].key);
   }
+  free (d->required);
   // free optional properties
   for (i = 0, p = d->optional; p[i].key != NULL; i++) {
     free ((char *) p[i].key);
   }
+  free (d->optional);
   free (d);
 }
 
@@ -1541,7 +1519,8 @@ static int checker_validate_properties (struct definition_t * root,
   /* check the property content */
   for (pair = def->pairs; pair != NULL; pair = pair->next) {
     /* check whether properties are either required or optional */
-    if (!checker_is_property (available, pair->key)) {
+    int type = checker_is_property (available, pair->key);
+    if (type == PROP_NONE) {
       if (strcmp (def->type, "Def")) {
 	logprint (LOG_ERROR, 
 		  "line %d: checker error, extraneous property `%s' is "
@@ -1560,7 +1539,7 @@ static int checker_validate_properties (struct definition_t * root,
 	errors++;
       }
       /* check variables in properties */
-      if (!checker_resolve_variable (root, def, pair->value))
+      if (!checker_resolve_variable (root, def, pair, type))
 	errors++;
     }
   }
@@ -1638,17 +1617,17 @@ static void netlist_free_value (struct value_t * value) {
 }
 
 /* Deletes pair list of a definition. */
-static void netlist_free_pairs (struct pair_t * pair) {
+static void netlist_free_pairs (struct pair_t * pp) {
   struct pair_t * np;
-  for (; pair != NULL; pair = np) {
-    np = pair->next;
+  for (; pp != NULL; pp = np) {
+    np = pp->next;
     struct value_t * nv, * value;
-    for (value = pair->value; value != NULL; value = nv) {
+    for (value = pp->value; value != NULL; value = nv) {
       nv = value->next;
       netlist_free_value (value);
     }
-    free (pair->key);
-    free (pair);
+    free (pp->key);
+    free (pp);
   }
 }
 
@@ -1852,7 +1831,9 @@ void netlist_status (void) {
   struct definition_t * cir;
   int count;
   logprint (LOG_STATUS, "netlist content\n");
-  for (def = qucs_definition_available; def->type != NULL; def++) {
+  qucs::hashiterator<module> it;
+  for (it = qucs::hashiterator<module> (module::modules); *it; ++it) {
+    def = it.currentVal()->definition;
     for (count = 0, cir = definition_root; cir != NULL; cir = cir->next) {
       if (!strcmp (def->type, cir->type)) count++;
     }
@@ -1924,11 +1905,8 @@ static void checker_subcircuit_args (struct definition_t * def,
       env->getChecker()->addDouble ("#subcircuit",
 				    pair->key, pair->value->value);
       // also put it into the environment
-      variable * v = new variable (pair->key);
-      eqn::constant * c = new eqn::constant (eqn::TAG_DOUBLE);
-      c->d = pair->value->value;
-      v->setConstant (c);
-      env->addVariable (v);
+      variable * v = checker_add_variable (env, pair->key, TAG_DOUBLE, true);
+      v->getConstant()->d = pair->value->value;
     }
   }
 }
