@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: circuit.h,v 1.56 2008/01/18 20:21:10 ela Exp $
+ * $Id: circuit.h,v 1.59 2008/10/08 16:32:58 ela Exp $
  *
  */
 
@@ -52,6 +52,12 @@ enum circuit_flag {
 #define MODFLAG(val,bit) if (val) flag |= (bit); else flag &= ~(bit);
 #define RETFLAG(bit)     ((flag & (bit)) != 0)
 
+#define CREATOR(val) \
+  val (); \
+  static circuit * create (void) { return new val (); } \
+  static struct define_t cirdef; \
+  static struct define_t * definition (void) { return &cirdef; }
+
 class node;
 class property;
 class substrate;
