@@ -1,7 +1,8 @@
 /*
  * amplifier.cpp - amplifier class implementation
  *
- * Copyright (C) 2004 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2004, 2008 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2008 Michael Margraf <Michael.Margraf@alumni.TU-Berlin.DE>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +19,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: amplifier.cpp,v 1.5 2007/08/07 20:43:08 ela Exp $
+ * $Id: amplifier.cpp,v 1.8 2008/10/07 20:15:32 ela Exp $
  *
  */
 
@@ -33,15 +34,7 @@
 # include <config.h>
 #endif
 
-#include <stdio.h>
-#include <stdlib.h>
-
-#include "complex.h"
-#include "object.h"
-#include "node.h"
-#include "circuit.h"
-#include "component_id.h"
-#include "constants.h"
+#include "component.h"
 #include "amplifier.h"
 
 /*! Constructor */
@@ -75,6 +68,16 @@ void amplifier::initSP (void) {
   setS (NODE_2, NODE_1, 4 * z0 * sqrt (z1 * z2) * g / (z1 + z0) / (z2 + z0));
 }
 
+void amplifier::calcNoiseSP (nr_double_t) {
+  nr_double_t g = getPropertyDouble ("G");
+  nr_double_t z2 = getPropertyDouble ("Z2");
+  nr_double_t NF = getPropertyDouble ("NF");
+  setN (NODE_1, NODE_1, 0);
+  setN (NODE_2, NODE_2, 4 * z0 * z2 * sqrt (g) * (NF - 1) / sqr (z2 + z0));
+  setN (NODE_1, NODE_2, 0);
+  setN (NODE_2, NODE_1, 0);
+}
+
 /*! DC model initialization. 
     An ideal amplifier is characterized by the following 
     Y-matrix:
@@ -108,6 +111,16 @@ void amplifier::initAC (void) {
   initDC ();
 }
 
+void amplifier::calcNoiseAC (nr_double_t) {
+  nr_double_t g = getPropertyDouble ("G");
+  nr_double_t z2 = getPropertyDouble ("Z2");
+  nr_double_t NF = getPropertyDouble ("NF");
+  setN (NODE_1, NODE_1, 0);
+  setN (NODE_2, NODE_2, 4 * sqrt (g) * (NF - 1) / z2);
+  setN (NODE_1, NODE_2, 0);
+  setN (NODE_2, NODE_1, 0);
+}
+
 /*! Transient model initialization.
 
     Idem than DC model.
@@ -115,3 +128,15 @@ void amplifier::initAC (void) {
 void amplifier::initTR (void) {
   initDC ();
 }
+
+// properties
+PROP_REQ [] = {
+  { "G", PROP_REAL, { 10, PROP_NO_STR }, PROP_MIN_VAL (1) },
+  PROP_NO_PROP };
+PROP_OPT [] = {
+  { "Z1", PROP_REAL, { 50, PROP_NO_STR }, PROP_POS_RANGE },
+  { "Z2", PROP_REAL, { 50, PROP_NO_STR }, PROP_POS_RANGE },
+  { "NF", PROP_REAL, { 1, PROP_NO_STR }, PROP_MIN_VAL (1) },
+  PROP_NO_PROP };
+struct define_t amplifier::cirdef =
+  { "Amp", 2, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_LINEAR, PROP_DEF };
