@@ -1,7 +1,8 @@
 /*
  * amplifier.h - amplifier class definitions
  *
- * Copyright (C) 2004 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2004, 2008 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2008 Michael Margraf <Michael.Margraf@alumni.TU-Berlin.DE>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +19,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: amplifier.h,v 1.3 2007/08/07 20:43:09 ela Exp $
+ * $Id: amplifier.h,v 1.6 2008/10/05 17:52:11 ela Exp $
  *
  */
 
@@ -34,10 +35,12 @@
 class amplifier : public circuit
 {
  public:
-  amplifier ();
+  CREATOR (amplifier);
   void initSP (void);
+  void calcNoiseSP (nr_double_t);
   void initDC (void);
   void initAC (void);
+  void calcNoiseAC (nr_double_t);
   void initTR (void);
 };
 
