@@ -1,7 +1,7 @@
 /*
  * attenuator.h - attenuator class definitions
  *
- * Copyright (C) 2003, 2004, 2005 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2003, 2004, 2005, 2008 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: attenuator.h,v 1.12 2005/06/02 18:17:51 raimi Exp $
+ * $Id: attenuator.h,v 1.14 2008/10/05 17:52:11 ela Exp $
  *
  */
 
@@ -28,7 +28,7 @@
 class attenuator : public circuit
 {
  public:
-  attenuator ();
+  CREATOR (attenuator);
   void initSP (void);
   void calcNoiseSP (nr_double_t);
   void initDC (void);
