@@ -1,7 +1,7 @@
 /*
  * capacitor.cpp - capacitor class implementation
  *
- * Copyright (C) 2003, 2004, 2005, 2006 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2003, 2004, 2005, 2006, 2008 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: capacitor.cpp,v 1.22 2008/01/10 20:00:00 ela Exp $
+ * $Id: capacitor.cpp,v 1.24 2008/10/07 20:15:32 ela Exp $
  *
  */
 
@@ -33,17 +33,7 @@
 # include <config.h>
 #endif
 
-#define __USE_BSD
-#define __USE_XOPEN
-#include <stdio.h>
-#include <stdlib.h>
-
-#include "complex.h"
-#include "object.h"
-#include "node.h"
-#include "circuit.h"
-#include "component_id.h"
-#include "constants.h"
+#include "component.h"
 #include "capacitor.h"
 
 /*!\brief Constructor */
@@ -141,3 +131,13 @@ void capacitor::initHB (void) {
 void capacitor::calcHB (nr_double_t frequency) {
   calcAC (frequency);
 }
+
+// properties
+PROP_REQ [] = {
+  { "C", PROP_REAL, { 1e-12, PROP_NO_STR }, PROP_NO_RANGE },
+  PROP_NO_PROP };
+PROP_OPT [] = {
+  { "V", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE },
+  PROP_NO_PROP };
+struct define_t capacitor::cirdef =
+  { "C", 2, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_LINEAR, PROP_DEF };
