@@ -1,7 +1,7 @@
 /*
  * cccs.h - cccs class definitions
  *
- * Copyright (C) 2003, 2004, 2006 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2003, 2004, 2006, 2008 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: cccs.h,v 1.9 2006/02/23 09:02:01 raimi Exp $
+ * $Id: cccs.h,v 1.11 2008/10/05 17:52:11 ela Exp $
  *
  */
 
@@ -28,7 +28,7 @@
 class cccs : public circuit
 {
  public:
-  cccs ();
+  CREATOR (cccs);
   void calcSP (nr_double_t);
   void initDC (void);
   void initAC (void);
