@@ -1,7 +1,7 @@
 /*
  * coaxline.h - coaxial cable class definitions
  *
- * Copyright (C) 2006 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2006, 2008 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: coaxline.h,v 1.2 2006/01/30 07:45:34 raimi Exp $
+ * $Id: coaxline.h,v 1.4 2008/10/05 17:52:11 ela Exp $
  *
  */
 
@@ -28,7 +28,7 @@
 class coaxline : public circuit
 {
  public:
-  coaxline ();
+  CREATOR (coaxline);
   void initSP (void);
   void calcSP (nr_double_t);
   void calcNoiseSP (nr_double_t);
