@@ -1,7 +1,7 @@
 /*
  * component_id.h - global component identifier header file
  *
- * Copyright (C) 2003-2008 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2003-2009 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: component_id.h,v 1.51 2008/04/01 14:52:08 ela Exp $
+ * $Id: component_id.h,v 1.65 2009/04/01 18:54:54 ela Exp $
  *
  */
 
@@ -73,8 +73,10 @@ enum circuit_type {
   CIR_RELAIS,
   CIR_TLINE,
   CIR_COAXLINE,
+  CIR_RECTANGULAR,
   CIR_TWISTEDPAIR,
   CIR_TLINE4P,
+  CIR_RLCG,
   CIR_IPROBE,
   CIR_VPROBE,
   CIR_SPFILE,
@@ -104,6 +106,7 @@ enum circuit_type {
   CIR_MSTEE,
   CIR_MSCROSS,
   CIR_MSVIA,
+  CIR_MSRSTUB,
   CIR_BONDWIRE,
 
   // coplanar components
@@ -133,17 +136,53 @@ enum circuit_type {
   CIR_XNOR,
   CIR_XOR,
   CIR_DIGISOURCE,
+  CIR_BUFFER,
 
   // verilog devices
   CIR_HBT_X,
-  CIR_hicumL2p1,
-  CIR_hicumL2p2,
+  CIR_hicumL2V2p1,
   CIR_mod_amp,
   CIR_hic2_full,
   CIR_log_amp,
   CIR_hic0_full,
   CIR_potentiometer,
-  CIR_MESFET
+  CIR_MESFET,
+  CIR_EKV26MOS,
+  CIR_hicumL0V1p2,
+  CIR_hicumL2V2p23,
+  CIR_photodiode,
+  CIR_phototransistor,
+
+  // digital verilog devices
+  CIR_dff_SR,
+  CIR_tff_SR,
+  CIR_jkff_SR,
+  CIR_gatedDlatch,
+  CIR_logic_1,
+  CIR_logic_0,
+  CIR_mux2to1,
+  CIR_mux4to1,
+  CIR_mux8to1,
+  CIR_DLS_nto1,
+  CIR_DLS_1ton,
+  CIR_andor4x2,
+  CIR_andor4x3,
+  CIR_andor4x4,
+  CIR_dmux2to4,
+  CIR_dmux3to8,
+  CIR_dmux4to16,
+  CIR_ha1b,
+  CIR_fa1b,
+  CIR_fa2b,
+  CIR_pad2bit,
+  CIR_pad3bit,
+  CIR_pad4bit,
+  CIR_binarytogrey4bit,
+  CIR_greytobinary4bit,
+  CIR_comp_1bit,
+  CIR_comp_2bit,
+  CIR_comp_4bit,
+  CIR_hpribin4bit,
 };
 
 #endif /* __COMPONENT_ID_H__ */
