@@ -1,7 +1,7 @@
 /*
  * coupler.h - ideal coupler class definitions
  *
- * Copyright (C) 2006 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2006, 2008 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: coupler.h,v 1.1 2006/01/04 10:40:33 raimi Exp $
+ * $Id: coupler.h,v 1.3 2008/10/05 17:52:11 ela Exp $
  *
  */
 
@@ -28,7 +28,7 @@
 class coupler : public circuit
 {
  public:
-  coupler ();
+  CREATOR (coupler);
   void initSP (void);
   void initDC (void);
   void initAC (void);
