@@ -1,7 +1,7 @@
 /*
  * bjt.h - bipolar junction transistor class definitions
  *
- * Copyright (C) 2004, 2005, 2006 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2004, 2005, 2006, 2008 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: bjt.h,v 1.22 2006/09/15 08:14:42 raimi Exp $
+ * $Id: bjt.h,v 1.24 2008/10/05 17:52:15 ela Exp $
  *
  */
 
@@ -28,7 +28,7 @@
 class bjt : public circuit
 {
  public:
-  bjt ();
+  CREATOR (bjt);
   void calcSP (nr_double_t);
   void calcNoiseSP (nr_double_t);
   void initSP (void);
