@@ -1,7 +1,7 @@
 /*
  * eqndefined.h - equation defined device class definitions
  *
- * Copyright (C) 2007 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2007, 2008 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: eqndefined.h,v 1.4 2007/09/16 16:49:40 ela Exp $
+ * $Id: eqndefined.h,v 1.6 2008/10/05 17:52:15 ela Exp $
  *
  */
 
@@ -28,7 +28,7 @@
 class eqndefined : public circuit
 {
  public:
-  eqndefined ();
+  CREATOR (eqndefined);
   ~eqndefined ();
   void initDC (void);
   void calcDC (void);
