@@ -1,7 +1,7 @@
 /*
  * nand.h - logical nand class definitions
  *
- * Copyright (C) 2005 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2005, 2008 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: nand.h,v 1.2 2005/11/25 08:27:05 raimi Exp $
+ * $Id: nand.h,v 1.4 2008/10/05 17:52:15 ela Exp $
  *
  */
 
@@ -28,7 +28,7 @@
 class logicnand : public digital
 {
  public:
-  logicnand ();
+  CREATOR (logicnand);
   void calcOutput (void);
   void calcDerivatives (void);
 };
