@@ -1,7 +1,7 @@
 /*
  * ground.cpp - ground class implementation
  *
- * Copyright (C) 2003, 2004 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2003, 2004, 2008 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: ground.cpp,v 1.5 2005/06/02 18:17:51 raimi Exp $
+ * $Id: ground.cpp,v 1.6 2008/12/19 19:46:21 ela Exp $
  *
  */
 
@@ -26,15 +26,8 @@
 # include <config.h>
 #endif
 
-#include <stdio.h>
-#include <stdlib.h>
-
-#include "complex.h"
-#include "object.h"
-#include "node.h"
-#include "circuit.h"
+#include "component.h"
 #include "ground.h"
-#include "component_id.h"
 
 ground::ground () : circuit (1) {
   type = CIR_GROUND;
