@@ -1,7 +1,7 @@
 /*
  * gyrator.h - gyrator class definitions
  *
- * Copyright (C) 2004 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2004, 2008 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: gyrator.h,v 1.7 2005/06/02 18:17:52 raimi Exp $
+ * $Id: gyrator.h,v 1.9 2008/10/05 17:52:11 ela Exp $
  *
  */
 
@@ -28,7 +28,7 @@
 class gyrator : public circuit
 {
  public:
-  gyrator ();
+  CREATOR (gyrator);
   void initSP (void);
   void initDC (void);
   void initAC (void);
