@@ -1,7 +1,7 @@
 /*
  * idc.cpp - DC current source class implementation
  *
- * Copyright (C) 2003, 2004 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2003, 2004, 2008 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: idc.cpp,v 1.10 2005/06/02 18:17:52 raimi Exp $
+ * $Id: idc.cpp,v 1.12 2008/10/07 20:15:32 ela Exp $
  *
  */
 
@@ -26,15 +26,7 @@
 # include <config.h>
 #endif
 
-#include <stdio.h>
-#include <stdlib.h>
-
-#include "complex.h"
-#include "object.h"
-#include "node.h"
-#include "circuit.h"
-#include "net.h"
-#include "component_id.h"
+#include "component.h"
 #include "idc.h"
 
 idc::idc () : circuit (2) {
@@ -70,3 +62,11 @@ void idc::initAC (void) {
 void idc::initTR (void) {
   initDC ();
 }
+
+// properties
+PROP_REQ [] = {
+  { "I", PROP_REAL, { 1e-3, PROP_NO_STR }, PROP_NO_RANGE }, PROP_NO_PROP };
+PROP_OPT [] = {
+  PROP_NO_PROP };
+struct define_t idc::cirdef =
+  { "Idc", 2, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_LINEAR, PROP_DEF };
